﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Microsoft.WindowsAzure.StorageClient;
using Microsoft.WindowsAzure;
using Microsoft.WindowsAzure.ServiceRuntime;

namespace ImageBlobStorage
{
    public partial class _Default : System.Web.UI.Page
    {

        CloudBlobContainer azureBlobContainer = null;
        CloudStorageAccount azureStorageAcct = null;
        CloudBlobClient azureBlobClient = null;
        BlobContainerPermissions azureBlobPermissions = null;
        string submissionDateTime = "";


        protected void Page_Load(object sender, EventArgs e)
        {
            SetUpBlobStorageAcct();

            azureBlobContainer =
               azureBlobClient.GetContainerReference("imagefiles");
            azureBlobContainer.CreateIfNotExist();

            azureBlobPermissions = new BlobContainerPermissions();
            azureBlobPermissions.PublicAccess =
               BlobContainerPublicAccessType.Container;
            azureBlobContainer.SetPermissions(azureBlobPermissions);

            UpdateImageList();

        }

        private void UpdateImageList()
        {
            var azureBlobs = azureBlobContainer.ListBlobs();
            var listOfBriefs = new List<ImageInfo>();

            foreach (var blobItem in azureBlobs)
            {
                var azureBlobRecord = azureBlobContainer.
                   GetBlobReference(blobItem.Uri.ToString());
                azureBlobRecord.FetchAttributes();

                listOfBriefs.Add(new ImageInfo()
                {
                    FileUri = blobItem.Uri,
                    ImageName = azureBlobRecord.Metadata["ImageName"],
                    Category = azureBlobRecord.Metadata["Category"],
                    DateSubmitted = azureBlobRecord.Metadata["DateSubmitted"]
                });
            }

            imageList.DataSource = listOfBriefs;
            imageList.DataBind();

        }

        private void SetUpBlobStorageAcct()
        {

            //var account = CloudStorageAccount.Parse(RoleEnvironment.GetConfigurationSettingValue("DataConnectionString"));
            azureStorageAcct = CloudStorageAccount.Parse(RoleEnvironment.GetConfigurationSettingValue("DataConnectionString"));
            //azureStorageAcct = CloudStorageAccount.FromConfigurationSetting("DataConnectionString");
            azureBlobClient = azureStorageAcct.CreateCloudBlobClient();
        }

        protected void RowCommandHandler(object sender, GridViewCommandEventArgs e)
        {
            if (e.CommandName == "DeleteImage")
            {
                var blobIndex = Convert.ToInt32(e.CommandArgument);
                var blobName = (Uri)imageList.DataKeys[blobIndex].Value;
                var blobContainer = azureBlobClient.
                   GetContainerReference("imagefiles");
                var blob = blobContainer.GetBlobReference(blobName.ToString());
                blob.DeleteIfExists();
            }
            UpdateImageList();
        }
        protected void lnkbtnSubmitImage_Click(object sender, EventArgs e)
        {
            submissionDateTime = GetCurrentDateTime();

            string videoFileExtension = System.IO.Path.GetExtension(
               imageUploadControl.FileName);

            var videoFilePrefix = imageNameBox.Text;
            var blob = azureBlobContainer.GetBlobReference(videoFilePrefix +
               videoFileExtension);
            var blobName = blob.Attributes.Properties.ToString();

            blob.UploadFromStream(imageUploadControl.FileContent);

            blob.Metadata["ImageName"] = imageNameBox.Text;
            blob.Metadata["Category"] = dropdwnCategory.SelectedItem.ToString();
            blob.Metadata["DateSubmitted"] = submissionDateTime;
            blob.SetMetadata();

            blob.Properties.ContentType =
               imageUploadControl.PostedFile.ContentType;
            blob.SetProperties();

            UpdateImageList();

            ClearTextboxFields();
        }

        private string GetCurrentDateTime()
        {
            DateTime currentTime = DateTime.Now;
            string currentTimeString = currentTime.ToShortDateString();
            return currentTimeString;
        }

        protected void lnkbtnClearFields_Click(object sender, EventArgs e)
        {
            ClearTextboxFields();
        }

        private void ClearTextboxFields()
        {
            imageNameBox.Text = "";
        }


    }
}
