﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Maps.MapControl;
using Microsoft.SharePoint.Client;

namespace Bing_LOB_UI
{
    public partial class MainPage : UserControl
    {
        ClientContext clientContext = null;
        Web web = null;

        List<StoreDetails> storeDetailsList = new List<StoreDetails>();
        List<StoreInfo> listOfStoreSummaries = new List<StoreInfo>(); 

        IEnumerable<ListItem> bcsStoreList;

        MapLayer OtherStores = new MapLayer();

        public MainPage()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            GetListsDataFromSharePoint();
        }

        private void GetListsDataFromSharePoint()
        {
            GetSPListData();
        }

        private void GetSPListData()
        {
            using (clientContext = new ClientContext("http://blueyonderdemo"))
            {
                web = clientContext.Web;
                clientContext.Load(web);
                var bcsListFromAzure = web.Lists.GetByTitle("Stores_From_Azure");
                CamlQuery query = new CamlQuery();
                IQueryable<ListItem> bcsListItems = bcsListFromAzure.GetItems(query);
                bcsStoreList = clientContext.LoadQuery(bcsListItems);
                clientContext.ExecuteQueryAsync(OnStoresRequestSucceeded, OnRequestFailed);
            }
        }

        private void OnStoresRequestSucceeded(object sender, ClientRequestSucceededEventArgs e)
        {
            Dispatcher.BeginInvoke(FillStoreList);
        }

        private void OnRequestFailed(object sender, ClientRequestFailedEventArgs e)
        {
            Dispatcher.BeginInvoke(() =>
            {
                MessageBox.Show("Error:  " + e.Message);
            });
        }

        private void FillStoreList()
        {
            storeDetailsList.Clear();

            foreach (var x in bcsStoreList)
            {
                StoreDetails objStoreDetails = new StoreDetails();
                objStoreDetails.StoreName = x.FieldValues.ElementAt(3).Value.ToString();
                objStoreDetails.StoreAddress = x.FieldValues.ElementAt(4).Value.ToString();
                objStoreDetails.StorePhone = x.FieldValues.ElementAt(5).Value.ToString();
                objStoreDetails.StoreHours = x.FieldValues.ElementAt(8).Value.ToString();
                objStoreDetails.StoreLocation = new Location(Convert.ToDouble(x.FieldValues.ElementAt(6).Value.ToString()), Convert.ToDouble(x.FieldValues.ElementAt(7).Value.ToString()));
                storeDetailsList.Add(objStoreDetails);

                StoreInfo objStoreSummary = new StoreInfo();
                objStoreSummary.StoreName = x.FieldValues.ElementAt(3).Value.ToString();
                objStoreSummary.StoreAddress = x.FieldValues.ElementAt(4).Value.ToString();
                objStoreSummary.StorePhone = x.FieldValues.ElementAt(5).Value.ToString();
                listOfStoreSummaries.Add(objStoreSummary);  
            }

            lstStores.ItemsSource = listOfStoreSummaries;

            AddStoresToMap();
        }

        private void AddStoresToMap()
        {
            Pushpins.Children.Clear();

            for (int i = 0; i < storeDetailsList.Count; i++)
            {
                string description = "Store: " + storeDetailsList[i].StoreName
                                 + "\nAddress: " + storeDetailsList[i].StoreAddress
                                 + "\nPhone: " + storeDetailsList[i].StorePhone
                                 + "\nHours: " + storeDetailsList[i].StoreHours;

                CreatePushpin(storeDetailsList[i].StoreLocation, description);
            }
        }

        private void CreatePushpin(Location location, string description)
        {
            Pushpin pushpin = new Pushpin();
            pushpin.Width = 7;
            pushpin.Height = 10;
            pushpin.Tag = description;
            pushpin.Location = location;
            Pushpins.AddChild(pushpin, location, PositionOrigin.Center);

            pushpin.MouseEnter += new MouseEventHandler(Shape_MouseEnter);
            pushpin.MouseLeave += new MouseEventHandler(Shape_MouseLeave);
        }

        private void Shape_MouseEnter(object sender, MouseEventArgs e)
        {        
            if (sender.ToString() == "Microsoft.Maps.MapControl.Pushpin")
            {
                Pushpin content = sender as Pushpin;
                Canvas.SetZIndex(content, 500);
                StoreTooltipText.Text = content.Name;
                StoreTooltipDescription.Text = content.Tag.ToString();
            }
            else
            {
                MapPolygon storeContent = sender as MapPolygon;
                Canvas.SetZIndex(storeContent, 500);
                StoreTooltipText.Text = "ID: " + storeContent.Name;
                StoreTooltipDescription.Text = storeContent.Tag.ToString();
            }

            Point point = e.GetPosition(MainMap);
            Location location = MainMap.ViewportPointToLocation(point);
            MapLayer.SetPosition(Tooltip, location);
            MapLayer.SetPositionOffset(Tooltip, new Point(25, -50));

            Tooltip.Visibility = Visibility.Visible;
        }

        private void Shape_MouseLeave(object sender, MouseEventArgs e)
        {
            UIElement content = sender as UIElement;
            Canvas.SetZIndex(content, 100);
            Tooltip.Visibility = Visibility.Collapsed;
        }

        private void btnZoomOnStore_Click(object sender, RoutedEventArgs e)
        {
            Location locationFilter = new Location();
            StoreInfo tempStoreRecord = new StoreInfo();

            tempStoreRecord = (StoreInfo)lstStores.SelectedItem;
            string storeNameFilter = tempStoreRecord.StoreName;

            var locationData = from store in storeDetailsList
                               where store.StoreName == storeNameFilter
                               select store;

            foreach (var item in locationData)
            {
                locationFilter = item.StoreLocation;
            }

            MainMap.SetView(locationFilter, 10); 
        }
    }
}





